==> pegasus-merchandise-api-1.3.1-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PsSkuCondVO.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.vo;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.io.Serializable;

/**
 * @author Roy.Chen
 * @version $Id: PubSkuCond.java, v 0.1 2015-08-06 10:16
 */
public class PsSkuCondVO extends BaseQueryCond implements Serializable {
    private Long    skuId;
    private String  skuCode;
    private String  skuName;

    private String  supplierId;
    private String  supplierName;
    private String  supplierCode;

    private String  brandId;
    private String  brandCode;
    private String  brandName;

    private String  categoryId;
    private String  categoryName;

    private String  channelCode;
    private String  channelName;

    private String  skuCateCode;
    private String  skuCateName;

    private String  channelCanSaleList;
    private String  channelOnShelfList;
    private String  channelOffShelfList;

    private String  customMadeCode;
    private String  combinedSkuRecipeCode;

    private Integer isSkuCustomMade;
    private Integer isCombinedSkuRecipeCode;

    public String getChannelCanSaleList() {
        return channelCanSaleList;
    }

    public void setChannelCanSaleList(String channelCanSaleList) {
        this.channelCanSaleList = channelCanSaleList;
    }

    public String getChannelOnShelfList() {
        return channelOnShelfList;
    }

    public void setChannelOnShelfList(String channelOnShelfList) {
        this.channelOnShelfList = channelOnShelfList;
    }

    public String getChannelOffShelfList() {
        return channelOffShelfList;
    }

    public void setChannelOffShelfList(String channelOffShelfList) {
        this.channelOffShelfList = channelOffShelfList;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public String getSkuName() {
        return skuName;
    }

    public void setSkuName(String skuName) {
        this.skuName = skuName;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getSupplierCode() {
        return supplierCode;
    }

    public void setSupplierCode(String supplierCode) {
        this.supplierCode = supplierCode;
    }

    public String getBrandCode() {
        return brandCode;
    }

    public void setBrandCode(String brandCode) {
        this.brandCode = brandCode;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }

    public String getSkuCateCode() {
        return skuCateCode;
    }

    public void setSkuCateCode(String skuCateCode) {
        this.skuCateCode = skuCateCode;
    }

    public String getSkuCateName() {
        return skuCateName;
    }

    public void setSkuCateName(String skuCateName) {
        this.skuCateName = skuCateName;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public String getBrandId() {
        return brandId;
    }

    public void setBrandId(String brandId) {
        this.brandId = brandId;
    }

    public String getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(String categoryId) {
        this.categoryId = categoryId;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public Long getSkuId() {
        return skuId;
    }

    public void setSkuId(Long skuId) {
        this.skuId = skuId;
    }

    public String getCustomMadeCode() {
        return customMadeCode;
    }

    public void setCustomMadeCode(String customMadeCode) {
        this.customMadeCode = customMadeCode;
    }

    public String getCombinedSkuRecipeCode() {
        return combinedSkuRecipeCode;
    }

    public void setCombinedSkuRecipeCode(String combinedSkuRecipeCode) {
        this.combinedSkuRecipeCode = combinedSkuRecipeCode;
    }

    public Integer getIsSkuCustomMade() {
        return isSkuCustomMade;
    }

    public void setIsSkuCustomMade(Integer isSkuCustomMade) {
        this.isSkuCustomMade = isSkuCustomMade;
    }

    public Integer getIsCombinedSkuRecipeCode() {
        return isCombinedSkuRecipeCode;
    }

    public void setIsCombinedSkuRecipeCode(Integer isCombinedSkuRecipeCode) {
        this.isCombinedSkuRecipeCode = isCombinedSkuRecipeCode;
    }

    //    public static void main(String[] args) {
    //        PsSkuCondVO cond = new PsSkuCondVO();
    //
    //        cond.setPagenum(20);
    //        cond.setCurrpage(3);
    //
    //        System.out.println(McReflectionUtil.getFieldValue(cond, "currpage"));
    //        System.out.println(McReflectionUtil.getFieldNameValue(cond));
    //
    //    }
}

==> pegasus-merchandise-api-3.2.7-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PsSkuCondVO.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.vo;

import com.thebeastshop.common.BaseQueryCond;

import java.io.Serializable;

/**
 * @author Roy.Chen
 * @version $Id: PubSkuCond.java, v 0.1 2015-08-06 10:16
 */
public class PsSkuCondVO extends BaseQueryCond implements Serializable {
    private Long    skuId;
    private String  skuCode;
    private String  skuName;

    private String  supplierId;
    private String  supplierName;
    private String  supplierCode;

    private String  brandId;
    private String  brandCode;
    private String  brandName;

    private String  categoryId;
    private String  categoryName;

    private String  channelCode;
    private String  channelName;

    private String  skuCateCode;
    private String  skuCateName;

    private String  channelCanSaleList;
    private String  channelOnShelfList;
    private String  channelOffShelfList;

    private String  customMadeCode;
    private String  combinedSkuRecipeCode;

    private Integer isSkuCustomMade;
    private Integer isCombinedSkuRecipeCode;

    public String getChannelCanSaleList() {
        return channelCanSaleList;
    }

    public void setChannelCanSaleList(String channelCanSaleList) {
        this.channelCanSaleList = channelCanSaleList;
    }

    public String getChannelOnShelfList() {
        return channelOnShelfList;
    }

    public void setChannelOnShelfList(String channelOnShelfList) {
        this.channelOnShelfList = channelOnShelfList;
    }

    public String getChannelOffShelfList() {
        return channelOffShelfList;
    }

    public void setChannelOffShelfList(String channelOffShelfList) {
        this.channelOffShelfList = channelOffShelfList;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public String getSkuName() {
        return skuName;
    }

    public void setSkuName(String skuName) {
        this.skuName = skuName;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getSupplierCode() {
        return supplierCode;
    }

    public void setSupplierCode(String supplierCode) {
        this.supplierCode = supplierCode;
    }

    public String getBrandCode() {
        return brandCode;
    }

    public void setBrandCode(String brandCode) {
        this.brandCode = brandCode;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }

    public String getSkuCateCode() {
        return skuCateCode;
    }

    public void setSkuCateCode(String skuCateCode) {
        this.skuCateCode = skuCateCode;
    }

    public String getSkuCateName() {
        return skuCateName;
    }

    public void setSkuCateName(String skuCateName) {
        this.skuCateName = skuCateName;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public String getBrandId() {
        return brandId;
    }

    public void setBrandId(String brandId) {
        this.brandId = brandId;
    }

    public String getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(String categoryId) {
        this.categoryId = categoryId;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public Long getSkuId() {
        return skuId;
    }

    public void setSkuId(Long skuId) {
        this.skuId = skuId;
    }

    public String getCustomMadeCode() {
        return customMadeCode;
    }

    public void setCustomMadeCode(String customMadeCode) {
        this.customMadeCode = customMadeCode;
    }

    public String getCombinedSkuRecipeCode() {
        return combinedSkuRecipeCode;
    }

    public void setCombinedSkuRecipeCode(String combinedSkuRecipeCode) {
        this.combinedSkuRecipeCode = combinedSkuRecipeCode;
    }

    public Integer getIsSkuCustomMade() {
        return isSkuCustomMade;
    }

    public void setIsSkuCustomMade(Integer isSkuCustomMade) {
        this.isSkuCustomMade = isSkuCustomMade;
    }

    public Integer getIsCombinedSkuRecipeCode() {
        return isCombinedSkuRecipeCode;
    }

    public void setIsCombinedSkuRecipeCode(Integer isCombinedSkuRecipeCode) {
        this.isCombinedSkuRecipeCode = isCombinedSkuRecipeCode;
    }

    //    public static void main(String[] args) {
    //        PsSkuCondVO cond = new PsSkuCondVO();
    //
    //        cond.setPagenum(20);
    //        cond.setCurrpage(3);
    //
    //        System.out.println(McReflectionUtil.getFieldValue(cond, "currpage"));
    //        System.out.println(McReflectionUtil.getFieldNameValue(cond));
    //
    //    }
}
